/*
author: Konrad Papala, konradp.com
contents:
#utils
#main section
#Installation
#Initialization
*/

//////////////////////////////////////////////////////////////////////////////////////
//##utils

//returns netopi preferences
function NetopiGetPref(){
	// Read preferences
	var nsIPrefServiceObj = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
	return nsIPrefServiceObj.getBranch("extensions.netopi."); 
};
   
//0 on first run, 1 on second etc.
function NetopiGetUsageCounter(){
	var wpref=NetopiGetPref();
	if(!wpref.prefHasUserValue("nUsgCnt"))return 0;
	return wpref.getIntPref("nUsgCnt"); 
};

   
//from http://developer.mozilla.org/en/docs/Code_snippets:Toolbar#Adding_button_by_default
//this adds Netopi button after address bar.
//executed once, on #Installation
function NetopiAddToolbarButton(){
try {
	var firefoxnav = document.getElementById("nav-bar");
	var curSet = firefoxnav.currentSet;
	if (curSet.indexOf("NetopiToolbarButton") == -1){
		 var set;
		 // Place the button after the urlbar
		 //alert("adding button");
		 if (curSet.indexOf("urlbar-container") != -1)
		   set = curSet.replace("urlbar-container", "urlbar-container,NetopiToolbarButton");//origninally was /urlbar-container/ - but what's that?
		 else  // at the end
		    set = firefoxnav.currentSet + ",NetopiToolbarButton";
		 firefoxnav.setAttribute("currentset", set);
		 firefoxnav.currentSet = set;
		 document.persist("nav-bar", "currentset");
		 // If you don't do the following call, funny things happen
		 try {
		   BrowserToolboxCustomizeDone(true);
		 }
		 catch (e) { }
		}
	}
	catch(e) { }
	//alert("button added");
};

//returns sidebar (global, not Netopi sidebar)
function NetopiGetSidebar() {
	//return top.document.getElementById('sidebar').contentWindow;
	//alert("NetopiGetSidebar0");
	var globSidebar=top.document.getElementById('sidebar');
	//alert("NetopiGetSidebar1");
	var cont=globSidebar.contentWindow;//something's wrong here when the netopi sidebar is shown a second time
	//alert("NetopiGetSidebar2");
	return cont;
}

//not used, loading an url into browser
function NetopiLoadBrowserUrl(url){
    // Set the browser window's location to the incoming URL
    window._content.document.location = url;
    // Make sure that we get the focus
    window.content.focus();
}

//opens an url in a new tab:
//http://developer.mozilla.org/en/docs/Code_snippets:Tabbed_browser#Opening_a_new_tab
function NetopiLoadBrowserUrlInNewTab(url){
	try{
		var mainWindow = window.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
					   .getInterface(Components.interfaces.nsIWebNavigation)
					   .QueryInterface(Components.interfaces.nsIDocShellTreeItem)
					   .rootTreeItem
					   .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
					   .getInterface(Components.interfaces.nsIDOMWindow);
	
		mainWindow.getBrowser().selectedTab=mainWindow.getBrowser().addTab(url);
	}catch(err){};
};

//loading a special page to Netopi sidebar.
//original url, like http://www.google.com
function NetopiLoadNetopiPage(url){
	try{
		//alert("d0");
		var Sidebar=NetopiGetSidebar();
		//alert("d1");
		if(!Sidebar)return;//hmmm not visible or what?
		//alert("d2");
		var SidebarBrowser=Sidebar.document.getElementById("NetopiSidebarBrowser");
		//alert("d3");
		if(!SidebarBrowser)return;//?
	}catch(err){return;};
	//alert("d4");
	//
	if(url.search("http:")!=0 && url.search("https://addons.mozilla.org/")==-1)//we don't accept https: (with an exception of mozilla's addons)... and other non-http protocols
	{
		var wurl="http://www.netopi.com/extension_stuff.php?do=no_url";//new
		SidebarBrowser.webNavigation.loadURI(wurl,0,null,null,null);
		return;
	};
	var wurl="http://www.netopi.com/show.php?url="+url;//new, this will do the rest	
	SidebarBrowser.webNavigation.loadURI(wurl,0,null,null,null);
};

/*
works, but how to react on tab change/close etc? and what when a new firefox instance is opened with many tabs? timer is better
window.addEventListener("load", function() { NetopiListener.init(); }, false);

var NetopiListener = {
  init: function() {
    var appcontent = document.getElementById("appcontent");   // browser
    if(appcontent)
      appcontent.addEventListener("DOMContentLoaded", this.onPageLoad, true);
  },

  onPageLoad: function(aEvent) {
    var doc = aEvent.originalTarget; // doc is document that triggered "onload" event
    // do something with the loaded page.
    // doc.location is a Location object (see below for a link).
    // You can use it to make your code executed on certain pages only.
    //if(doc.location.href.search("forum") > -1)  alert("a forum page is loaded");
	alert(doc.location.href);
  }
}
*/

///////////////////////////////////////////////////////////////////////////
//##main section

var Netopi_prevlocation;//used by NetopiTimer to detect current url changes
var Netopi_TimerID;

//called when Netopi sidebar is shown (by user)
function onLoadNetopiSidebar(){
	//alert("onload");
	try{
		Netopi_prevlocation=content.document.location.href;
		NetopiLoadNetopiPage(content.document.location.href);
	}catch(err){};
};

//when Netopi sidebar is closed
function onUnLoadNetopiSidebar(){
	//alert("unloaded");
	//necessary, since every time user toogles Netopi sidebar, SetInterval is executed again.
	//not true, it looks like on unload the timers are deleted automatically
	//clearInterval ( Netopi_TimerID );
};


function NetopiTimer(){
	try{
		var curloc=content.document.location.href;
		if(curloc==Netopi_prevlocation)return;//nothing changed
		Netopi_prevlocation=curloc;
		NetopiLoadNetopiPage(curloc);
	}
	catch(err){};
};

////////////////////////////
//let's ride (this is executed every time sidebar is shown)
Netopi_TimerID=setInterval ( "NetopiTimer()", 500 );

//tests:

//////////////////////////////////////////////////////////////////////////////
//##Installation

//usage counter: 
var Netopi_nUsgCnt=NetopiGetUsageCounter();
//let's increase usage count:
var wpref=NetopiGetPref();
wpref.setIntPref("nUsgCnt",Netopi_nUsgCnt+1); 
if(Netopi_nUsgCnt==0)setTimeout('NetopiInstall()',3000);

function NetopiInstall(){//first usage, on first install only:
	//alert(Netopi_nUsgCnt);
	
	/*
	var msg="";
	msg+="Thank you for installing Netopi!\n\n"; 
	msg+="You can now add public reviews to any website you want\n";
	msg+="and read opinions expressed by others\n\n";
	msg+="You can now click the Netopi button (available on your toolbar) or hit Ctrl+Shift+S"; 
	alert(msg);
	*/
	//help website in a new tab: introduction to Netopi
	
	//NetopiLoadBrowserUrlInNewTab("http://www.konradp.com/products/extension_stuff.php?do=first_run");//old
	NetopiLoadBrowserUrlInNewTab("http://www.Netopi.com/extension_stuff.php?do=first_run");//new
	//toolbar button:
	NetopiAddToolbarButton();//setTimeout('NetopiAddToolbarButton()',3000);
	//let's display Netopi sidebar upon installation.
	try{
		toggleSidebar("viewNetopiSidebar", true);
	}catch(err){};
};



